@@ -13,7 +13,11 @@ from . import core, config
 logger = logging.getLogger(__name__)
 
 
-@njit(fastmath=True)
+@njit(
+    # "(f8[:], f8[:], i8, b1[:], b1[:], i8[:], i8, i8, i8, f8[:, :, :], i8[:, :, :],"
+    # "b1)",
+    fastmath=True,
+)
 def _compute_diagonal(
     T_A,
     T_B,
@@ -34,31 +38,31 @@ def _compute_diagonal(
 
     Parameters
     ----------
-    T_A : ndarray
+    T_A : numpy.ndarray
         The time series or sequence for which to compute the matrix profile
 
-    T_B : ndarray
+    T_B : numpy.ndarray
         The time series or sequence that will be used to annotate T_A. For every
         subsequence in T_A, its nearest neighbor in T_B will be recorded.
 
     m : int
         Window size
 
-    P : ndarray
+    P : numpy.ndarray
         Matrix profile
 
-    I : ndarray
+    I : numpy.ndarray
         Matrix profile indices
 
-    T_A_subseq_isfinite : ndarray
+    T_A_subseq_isfinite : numpy.ndarray
         A boolean array that indicates whether a subsequence in `T_A` contains a
         `np.nan`/`np.inf` value (False)
 
-    T_B_subseq_isfinite : ndarray
+    T_B_subseq_isfinite : numpy.ndarray
         A boolean array that indicates whether a subsequence in `T_B` contains a
         `np.nan`/`np.inf` value (False)
 
-    diags : ndarray
+    diags : numpy.ndarray
         The diag of diagonals to process and compute
 
     diags_start_idx : int
@@ -90,7 +94,7 @@ def _compute_diagonal(
             iter_range = range(-k, min(n_A - m + 1, n_B - m + 1 - k))
 
         for i in iter_range:
-            if i == 0 or i == k or (k < 0 and i == -k):
+            if i == 0 or (k < 0 and i == -k):
                 D_squared = np.linalg.norm(T_B[i + k : i + k + m] - T_A[i : i + m]) ** 2
             else:
                 D_squared = np.abs(
@@ -127,7 +131,11 @@ def _compute_diagonal(
     return
 
 
-@njit(parallel=True, fastmath=True)
+@njit(
+    # "(f8[:], f8[:], i8, b1[:], b1[:], i8[:], b1)",
+    parallel=True,
+    fastmath=True,
+)
 def _aamp(T_A, T_B, m, T_A_subseq_isfinite, T_B_subseq_isfinite, diags, ignore_trivial):
     """
     A Numba JIT-compiled version of AAMP for parallel computation of the matrix
@@ -135,25 +143,25 @@ def _aamp(T_A, T_B, m, T_A_subseq_isfinite, T_B_subseq_isfinite, diags, ignore_t
 
     Parameters
     ----------
-    T_A : ndarray
+    T_A : numpy.ndarray
         The time series or sequence for which to compute the matrix profile
 
-    T_B : ndarray
+    T_B : numpy.ndarray
         The time series or sequence that will be used to annotate T_A. For every
         subsequence in T_A, its nearest neighbor in T_B will be recorded.
 
     m : int
         Window size
 
-    T_A_subseq_isfinite : ndarray
+    T_A_subseq_isfinite : numpy.ndarray
         A boolean array that indicates whether a subsequence in `T_A` contains a
         `np.nan`/`np.inf` value (False)
 
-    T_B_subseq_isfinite : ndarray
+    T_B_subseq_isfinite : numpy.ndarray
         A boolean array that indicates whether a subsequence in `T_B` contains a
         `np.nan`/`np.inf` value (False)
 
-    diags : ndarray
+    diags : numpy.ndarray
         The diag of diagonals to process and compute
 
     ignore_trivial : bool
@@ -162,10 +170,10 @@ def _aamp(T_A, T_B, m, T_A_subseq_isfinite, T_B_subseq_isfinite, diags, ignore_t
 
     Returns
     -------
-    P : ndarray
+    P : numpy.ndarray
         Matrix profile
 
-    I : ndarray
+    I : numpy.ndarray
         Matrix profile indices
 
     Notes
@@ -179,11 +187,11 @@ def _aamp(T_A, T_B, m, T_A_subseq_isfinite, T_B_subseq_isfinite, diags, ignore_t
     n_B = T_B.shape[0]
     l = n_A - m + 1
     n_threads = numba.config.NUMBA_NUM_THREADS
-    P = np.full((n_threads, l, 3), np.inf)
-    I = np.full((n_threads, l, 3), -1, np.int64)
+    P = np.full((n_threads, l, 3), np.inf, dtype=np.float64)
+    I = np.full((n_threads, l, 3), -1, dtype=np.int64)
 
     ndist_counts = core._count_diagonal_ndist(diags, m, n_A, n_B)
-    diags_ranges = core._get_array_ranges(ndist_counts, n_threads)
+    diags_ranges = core._get_array_ranges(ndist_counts, n_threads, False)
 
     for thread_idx in prange(n_threads):
         # Compute and update P, I within a single thread while avoiding race conditions
@@ -229,13 +237,13 @@ def aamp(T_A, m, T_B=None, ignore_trivial=True):
 
     Parameters
     ----------
-    T_A : ndarray
+    T_A : numpy.ndarray
         The time series or sequence for which to compute the matrix profile
 
     m : int
         Window size
 
-    T_B : ndarray, default None
+    T_B : numpy.ndarray, default None
         The time series or sequence that will be used to annotate T_A. For every
         subsequence in T_A, its nearest neighbor in T_B will be recorded. Default is
         `None` which corresponds to a self-join.
@@ -246,7 +254,7 @@ def aamp(T_A, m, T_B=None, ignore_trivial=True):
 
     Returns
     -------
-    out : ndarray
+    out : numpy.ndarray
         The first column consists of the matrix profile, the second column
         consists of the matrix profile indices.
 
@@ -290,9 +298,9 @@ def aamp(T_A, m, T_B=None, ignore_trivial=True):
     out = np.empty((l, 4), dtype=object)
 
     if ignore_trivial:
-        diags = np.arange(excl_zone + 1, n_A - m + 1)
+        diags = np.arange(excl_zone + 1, n_A - m + 1, dtype=np.int64)
     else:
-        diags = np.arange(-(n_A - m + 1) + 1, n_B - m + 1)
+        diags = np.arange(-(n_A - m + 1) + 1, n_B - m + 1, dtype=np.int64)
 
     P, I = _aamp(
         T_A, T_B, m, T_A_subseq_isfinite, T_B_subseq_isfinite, diags, ignore_trivial
