@@ -48,6 +48,12 @@ def gpu_ostinato(Ts, m, device_id=0, normalize=True):
         The subsequence index within time series `Ts[central_motif_Ts_idx]` the contains
         most central consensus motif
 
+    See Also
+    --------
+    stumpy.ostinato : Find the z-normalized consensus motif of multiple time series
+    stumpy.ostinatoed : Find the z-normalized consensus motif of multiple time series
+        with a distributed dask cluster
+
     Notes
     -----
     `DOI: 10.1109/ICDM.2019.00140 \
@@ -67,6 +73,19 @@ def gpu_ostinato(Ts, m, device_id=0, normalize=True):
     distance to nearest neighbors in all other time series. To find this
     central motif it is necessary to search the subsequences with the
     best radius via `stumpy.ostinato._get_central_motif`
+
+    Examples
+    --------
+    >>> from numba import cuda
+    >>> if __name__ == "__main__":
+    ...     all_gpu_devices = [device.id for device in cuda.list_devices()]
+    ...     stumpy.gpu_ostinatoe(
+    ...         [np.array([584., -11., 23., 79., 1001., 0., 19.]),
+    ...          np.array([600., -10., 23., 17.]),
+    ...          np.array([  1.,   9.,  6.,  0.])],
+    ...         m=3,
+    ...         device_id=all_gpu_devices)
+    (1.2370237678153826, 0, 4)
     """
     M_Ts = [None] * len(Ts)
     Σ_Ts = [None] * len(Ts)
