@@ -20,33 +20,33 @@ def _multi_mass_absolute(Q, T, m, Q_subseq_isfinite, T_subseq_isfinite):
 
     Parameters
     ----------
-    Q : ndarray
+    Q : numpy.ndarray
         Query array or subsequence
 
-    T : ndarray
+    T : numpy.ndarray
         Time series array or sequence
 
     m : int
         Window size
 
-    Q_subseq_isfinite : ndarray
+    Q_subseq_isfinite : numpy.ndarray
         A boolean array that indicates whether a subsequence in `Q` contains a
         `np.nan`/`np.inf` value (False)
 
-    T_subseq_isfinite : ndarray
+    T_subseq_isfinite : numpy.ndarray
         A boolean array that indicates whether a subsequence in `T` contains a
         `np.nan`/`np.inf` value (False)
 
     Returns
     -------
-    D : ndarray
+    D : numpy.ndarray
         Multi-dimensional non-normalized (i.e., without z-normalization) distance
         profile
     """
     d, n = T.shape
     k = n - m + 1
 
-    D = np.empty((d, k), dtype="float64")
+    D = np.empty((d, k), dtype=np.float64)
 
     for i in range(d):
         if np.any(~Q_subseq_isfinite[i]):
@@ -66,7 +66,7 @@ def maamp_subspace(T, m, subseq_idx, nn_idx, k, include=None, discords=False):
 
     Parameters
     ----------
-    T : ndarray
+    T : numpy.ndarray
         The time series or sequence for which the multi-dimensional matrix profile,
         multi-dimensional matrix profile indices were computed
 
@@ -83,7 +83,7 @@ def maamp_subspace(T, m, subseq_idx, nn_idx, k, include=None, discords=False):
         The subset number of dimensions out of `D = T.shape[0]`-dimensions to return
         the subspace for
 
-    include : ndarray, default None
+    include : numpy.ndarray, default None
         A list of (zero-based) indices corresponding to the dimensions in `T` that
         must be included in the constrained multidimensional motif search.
         For more information, see Section IV D in:
@@ -97,7 +97,7 @@ def maamp_subspace(T, m, subseq_idx, nn_idx, k, include=None, discords=False):
 
     Returns
     -------
-        S : ndarray
+        S : numpy.ndarray
         An array of that contains the `k`th-dimensional subspace for the subsequence
         with index equal to `motif_idx`
     """
@@ -112,27 +112,25 @@ def maamp_subspace(T, m, subseq_idx, nn_idx, k, include=None, discords=False):
     return S
 
 
-def _query_maamp_profile(
+def _maamp_multi_distance_profile(
     query_idx, T_A, T_B, m, excl_zone, T_B_subseq_isfinite, include=None, discords=False
 ):
     """
     Multi-dimensional wrapper to compute the multi-dimensional non-normalized (i.e.,
-    without z-normalization) matrix profile and the multi-dimensional matrix profile
-    index for a given query window within the times series or sequence that is denoted
-    by the `query_idx` index. Essentially, this is a convenience wrapper around
-    `_multi_mass_absolute`.
+    without z-normalization) distance profile for a given query window within the
+    times series or sequence that is denoted by the `query_idx` index. Essentially,
+    this is a convenience wrapper around `_multi_mass_absolute`.
 
     Parameters
     ----------
     query_idx : int
-        The window index to calculate the first multi-dimensional matrix profile and
-        multi-dimensional matrix profile indices
+        The window index to calculate the multi-dimensional distance profile
 
-    T_A : ndarray
-        The time series or sequence for which the multi-dimensional matrix profile and
-        multi-dimensional matrix profile indices
+    T_A : numpy.ndarray
+        The time series or sequence for which the multi-dimensional distance profile
+        will be returned
 
-    T_B : ndarray
+    T_B : numpy.ndarray
         The time series or sequence that contains your query subsequences
 
     m : int
@@ -141,11 +139,11 @@ def _query_maamp_profile(
     excl_zone : int
         The half width for the exclusion zone relative to the `query_idx`.
 
-    T_B_subseq_isfinite : ndarray
+    T_B_subseq_isfinite : numpy.ndarray
         A boolean array that indicates whether a subsequence in `T_B` contains a
         `np.nan`/`np.inf` value (False)
 
-    include : ndarray, default None
+    include : numpy.ndarray, default None
         A list of (zero-based) indices corresponding to the dimensions in `T` that
         must be included in the constrained multidimensional motif search.
         For more information, see Section IV D in:
@@ -159,13 +157,9 @@ def _query_maamp_profile(
 
     Returns
     -------
-    P : ndarray
-        Multi-dimensional matrix profile for the window with index equal to
+    D : numpy.ndarray
+        Multi-dimensional distance profile for the window with index equal to
         `query_idx`
-
-    I : ndarray
-        Multi-dimensional matrix profile indices for the window with index
-        equal to `query_idx`
     """
     d, n = T_A.shape
     k = n - m + 1
@@ -187,62 +181,35 @@ def _query_maamp_profile(
     else:
         D[start_row_idx:].sort(axis=0, kind="mergesort")
 
-    D_prime = np.zeros(k)
+    D_prime = np.zeros(k, dtype=np.float64)
     for i in range(d):
         D_prime[:] = D_prime + D[i]
         D[i, :] = D_prime / (i + 1)
 
     core.apply_exclusion_zone(D, query_idx, excl_zone)
 
-    P = np.full(d, np.inf, dtype="float64")
-    I = np.full(d, -1, dtype="int64")
-
-    for i in range(d):
-        min_index = np.argmin(D[i])
-        I[i] = min_index
-        P[i] = D[i, min_index]
-        if np.isinf(P[i]):  # pragma nocover
-            I[i] = -1
-
-    return P, I
+    return D
 
 
-def _get_first_maamp_profile(
-    start, T_A, T_B, m, excl_zone, T_B_subseq_isfinite, include=None, discords=False
-):
+def maamp_multi_distance_profile(query_idx, T, m, include=None, discords=False):
     """
-    Multi-dimensional wrapper to compute the non-normalized (i.e., without
-    z-normalization multi-dimensional matrix profile and multi-dimensional matrix
-    profile index for a given window within the times series or sequence that is denoted
-    by the `start` index. Essentially, this is a convenience wrapper around
-    `_multi_mass_absolute`. This is a convenience wrapper for the `_query_maamp_profile`
-    function but does not return the multi-dimensional matrix profile subspace.
+    Multi-dimensional wrapper to compute the multi-dimensional non-normalized (i.e.,
+    without z-normalization) distance profile for a given query window within the
+    times series or sequence that is denoted by the `query_idx` index.
 
     Parameters
     ----------
-    start : int
-        The window index to calculate the first multi-dimensional matrix profile,
-        multi-dimensional matrix profile indices, and multi-dimensional subspace.
+    query_idx : int
+        The window index to calculate the multi-dimensional distance profile
 
-    T_A : ndarray
-        The time series or sequence for which the multi-dimensional matrix profile,
-        multi-dimensional matrix profile indices, and multi-dimensional subspace will be
-        returned
-
-    T_B : ndarray
-        The time series or sequence that contains your query subsequences
+    T : numpy.ndarray
+        The time series or sequence for which the multi-dimensional distance profile
+        will be returned
 
     m : int
         Window size
 
-    excl_zone : int
-        The half width for the exclusion zone relative to the `start`.
-
-    T_B_subseq_isfinite : ndarray
-        A boolean array that indicates whether a subsequence in `Q` contains a
-        `np.nan`/`np.inf` value (False)
-
-    include : ndarray, default None
+    include : numpy.ndarray, default None
         A list of (zero-based) indices corresponding to the dimensions in `T` that
         must be included in the constrained multidimensional motif search.
         For more information, see Section IV D in:
@@ -256,21 +223,114 @@ def _get_first_maamp_profile(
 
     Returns
     -------
-    P : ndarray
+    D : numpy.ndarray
+        Multi-dimensional distance profile for the window with index equal to
+        `query_idx`
+    """
+    T, T_subseq_isfinite = core.preprocess_non_normalized(T, m)
+
+    if T.ndim <= 1:  # pragma: no cover
+        err = f"T is {T.ndim}-dimensional and must be at least 1-dimensional"
+        raise ValueError(f"{err}")
+
+    core.check_window_size(m, max_size=T.shape[1])
+
+    if include is not None:  # pragma: no cover
+        include = mstump._preprocess_include(include)
+
+    excl_zone = int(
+        np.ceil(m / config.STUMPY_EXCL_ZONE_DENOM)
+    )  # See Definition 3 and Figure 3
+
+    D = _maamp_multi_distance_profile(
+        query_idx, T, T, m, excl_zone, T_subseq_isfinite, include, discords
+    )
+
+    return D
+
+
+def _get_first_maamp_profile(
+    start, T_A, T_B, m, excl_zone, T_B_subseq_isfinite, include=None, discords=False
+):
+    """
+    Multi-dimensional wrapper to compute the non-normalized (i.e., without
+    z-normalization multi-dimensional matrix profile and multi-dimensional matrix
+    profile index for a given window within the times series or sequence that is denoted
+    by the `start` index. Essentially, this is a convenience wrapper around
+    `_multi_mass_absolute`. This is a convenience wrapper for the
+    `_maamp_multi_distance_profile` function but does not return the multi-dimensional
+    matrix profile subspace.
+
+    Parameters
+    ----------
+    start : int
+        The window index to calculate the first multi-dimensional matrix profile,
+        multi-dimensional matrix profile indices, and multi-dimensional subspace.
+
+    T_A : numpy.ndarray
+        The time series or sequence for which the multi-dimensional matrix profile,
+        multi-dimensional matrix profile indices, and multi-dimensional subspace will be
+        returned
+
+    T_B : numpy.ndarray
+        The time series or sequence that contains your query subsequences
+
+    m : int
+        Window size
+
+    excl_zone : int
+        The half width for the exclusion zone relative to the `start`.
+
+    T_B_subseq_isfinite : numpy.ndarray
+        A boolean array that indicates whether a subsequence in `Q` contains a
+        `np.nan`/`np.inf` value (False)
+
+    include : numpy.ndarray, default None
+        A list of (zero-based) indices corresponding to the dimensions in `T` that
+        must be included in the constrained multidimensional motif search.
+        For more information, see Section IV D in:
+
+        `DOI: 10.1109/ICDM.2017.66 \
+        <https://www.cs.ucr.edu/~eamonn/Motif_Discovery_ICDM.pdf>`__
+
+    discords : bool, default False
+        When set to `True`, this reverses the distance profile to favor discords rather
+        than motifs. Note that indices in `include` are still maintained and respected.
+
+    Returns
+    -------
+    P : numpy.ndarray
         Multi-dimensional matrix profile for the window with index equal to
         `start`
 
-    I : ndarray
+    I : numpy.ndarray
         Multi-dimensional matrix profile indices for the window with index
         equal to `start`
     """
-    P, I = _query_maamp_profile(
+    D = _maamp_multi_distance_profile(
         start, T_A, T_B, m, excl_zone, T_B_subseq_isfinite, include, discords
     )
+
+    d = T_A.shape[0]
+    P = np.full(d, np.inf, dtype=np.float64)
+    I = np.full(d, -1, dtype=np.int64)
+
+    for i in range(d):
+        min_index = np.argmin(D[i])
+        I[i] = min_index
+        P[i] = D[i, min_index]
+        if np.isinf(P[i]):  # pragma nocover
+            I[i] = -1
+
     return P, I
 
 
-@njit(parallel=True, fastmath=True)
+@njit(
+    # "(i8, i8, i8, f8[:, :], f8[:, :], i8, i8, b1[:, :], b1[:, :], f8[:, :],"
+    # "f8[:, :], f8[:, :], f8[:, :], f8[:, :])",
+    parallel=True,
+    fastmath=True,
+)
 def _compute_multi_D(
     d,
     k,
@@ -302,10 +362,10 @@ def _compute_multi_D(
     idx : int
         The row index in `T`
 
-    D : ndarray
+    D : numpy.ndarray
         The output distance profile
 
-    T : ndarray
+    T : numpy.ndarray
         The time series or sequence for which to compute the matrix profile
 
     m : int
@@ -315,27 +375,27 @@ def _compute_multi_D(
         The half width for the exclusion zone relative to the current
         sliding window
 
-    T_A_subseq_isfinite : ndarray
+    T_A_subseq_isfinite : numpy.ndarray
         A boolean array that indicates whether a subsequence in `T_A` contains a
         `np.nan`/`np.inf` value (False)
 
-    T_B_subseq_isfinite : ndarray
+    T_B_subseq_isfinite : numpy.ndarray
         A boolean array that indicates whether a subsequence in `T_B` contains a
         `np.nan`/`np.inf` value (False)
 
-    T_A_subseq_squared : ndarray
+    T_A_subseq_squared : numpy.ndarray
+        The rolling sum for `T_A * T_A`
+
+    T_B_subseq_squared : numpy.ndarray
         The rolling sum for `T_B * T_B`
 
-    T_B_subseq_squared : ndarray
-        The rolling sum for `T_B * T_B`
-
-    QT_even : ndarray
+    QT_even : numpy.ndarray
         Dot product between some query sequence,`Q`, and time series, `T`
 
-    QT_odd : ndarray
+    QT_odd : numpy.ndarray
         Dot product between some query sequence,`Q`, and time series, `T`
 
-    QT_first : ndarray
+    QT_first : numpy.ndarray
         QT for the first window relative to the current sliding window
 
     Notes
@@ -417,7 +477,7 @@ def _maamp(
 
     Parameters
     ----------
-    T: ndarray
+    T: numpy.ndarray
         The time series or sequence for which to compute the multi-dimensional
         matrix profile
 
@@ -433,24 +493,24 @@ def _maamp(
         The half width for the exclusion zone relative to the current
         sliding window
 
-    T_A_subseq_isfinite : ndarray
+    T_A_subseq_isfinite : numpy.ndarray
         A boolean array that indicates whether a subsequence in `T_A` contains a
         `np.nan`/`np.inf` value (False)
 
-    T_B_subseq_isfinite : ndarray
+    T_B_subseq_isfinite : numpy.ndarray
         A boolean array that indicates whether a subsequence in `T_B` contains a
         `np.nan`/`np.inf` value (False)
 
-    T_A_subseq_squared : ndarray
+    T_A_subseq_squared : numpy.ndarray
         The rolling sum for `T_A * T_A`
 
-    T_B_subseq_squared : ndarray
+    T_B_subseq_squared : numpy.ndarray
         The rolling sum for `T_B * T_B`
 
-    QT : ndarray
+    QT : numpy.ndarray
         Dot product between some query sequence,`Q`, and time series, `T`
 
-    QT_first : ndarray
+    QT_first : numpy.ndarray
         QT for the first window relative to the current sliding window
 
     k : int
@@ -460,7 +520,7 @@ def _maamp(
         The starting index value along T_B for which to start the matrix
         profile calculation. Default is 1.
 
-    include : ndarray, default None
+    include : numpy.ndarray, default None
         A list of (zero-based) indices corresponding to the dimensions in `T` that
         must be included in the constrained multidimensional motif search.
         For more information, see Section IV D in:
@@ -474,12 +534,12 @@ def _maamp(
 
     Returns
     -------
-    P : ndarray
+    P : numpy.ndarray
         The multi-dimensional matrix profile. Each row of the array corresponds
         to each matrix profile for a given dimension (i.e., the first row is the
         1-D matrix profile and the second row is the 2-D matrix profile).
 
-    I : ndarray
+    I : numpy.ndarray
         The multi-dimensional matrix profile index where each row of the array
         corresponds to each matrix profile index for a given dimension.
 
@@ -494,17 +554,17 @@ def _maamp(
     QT_even = QT.copy()
     d = T.shape[0]
 
-    P = np.empty((d, range_stop - range_start), dtype=float)
-    I = np.empty((d, range_stop - range_start), dtype=int)
-    D = np.empty((d, k), dtype=float)
-    D_prime = np.empty(k, dtype=float)
+    P = np.empty((d, range_stop - range_start), dtype=np.float64)
+    I = np.empty((d, range_stop - range_start), dtype=np.int64)
+    D = np.empty((d, k), dtype=np.float64)
+    D_prime = np.empty(k, dtype=np.float64)
     start_row_idx = 0
 
     if include is not None:
-        tmp_swap = np.empty((include.shape[0], k))
+        tmp_swap = np.empty((include.shape[0], k), dtype=np.float64)
         restricted_indices = include[include < include.shape[0]]
         unrestricted_indices = include[include >= include.shape[0]]
-        mask = np.ones(include.shape[0], bool)
+        mask = np.ones(include.shape[0], dtype=bool)
         mask[restricted_indices] = False
 
     for idx in range(range_start, range_stop):
@@ -559,7 +619,7 @@ def maamp(T, m, include=None, discords=False):
 
     Parameters
     ----------
-    T : ndarray
+    T : numpy.ndarray
         The time series or sequence for which to compute the multi-dimensional
         matrix profile. Each row in `T` represents data from a different
         dimension while each column in `T` represents data from the same
@@ -568,7 +628,7 @@ def maamp(T, m, include=None, discords=False):
     m : int
         Window size
 
-    include : list, ndarray, default None
+    include : list, numpy.ndarray, default None
         A list of (zero-based) indices corresponding to the dimensions in `T` that
         must be included in the constrained multidimensional motif search.
         For more information, see Section IV D in:
@@ -584,12 +644,12 @@ def maamp(T, m, include=None, discords=False):
 
     Returns
     -------
-    P : ndarray
+    P : numpy.ndarray
         The multi-dimensional matrix profile. Each row of the array corresponds
         to each matrix profile for a given dimension (i.e., the first row is
         the 1-D matrix profile and the second row is the 2-D matrix profile).
 
-    I : ndarray
+    I : numpy.ndarray
         The multi-dimensional matrix profile index where each row of the array
         corresponds to each matrix profile index for a given dimension.
 
@@ -623,8 +683,8 @@ def maamp(T, m, include=None, discords=False):
         np.ceil(m / config.STUMPY_EXCL_ZONE_DENOM)
     )  # See Definition 3 and Figure 3
 
-    P = np.empty((d, k), dtype="float64")
-    I = np.empty((d, k), dtype="int64")
+    P = np.empty((d, k), dtype=np.float64)
+    I = np.empty((d, k), dtype=np.int64)
 
     start = 0
     stop = k
