@@ -10,7 +10,7 @@ from numba import njit, prange
 from functools import lru_cache
 
 from . import core, config
-from .maamp import maamp, maamp_subspace
+from .maamp import maamp_multi_distance_profile, maamp, maamp_subspace
 
 logger = logging.getLogger(__name__)
 
@@ -21,7 +21,7 @@ def _preprocess_include(include):
 
     Parameters
     ----------
-    include : ndarray
+    include : numpy.ndarray
         A list of (zero-based) indices corresponding to the dimensions in `T` that
         must be included in the constrained multidimensional motif search.
         For more information, see Section IV D in:
@@ -31,7 +31,7 @@ def _preprocess_include(include):
 
     Returns
     -------
-    include : ndarray
+    include : numpy.ndarray
         Process `include` and remove any redundant index values
     """
     include = np.asarray(include)
@@ -58,10 +58,10 @@ def _apply_include(
 
     Parameters
     ----------
-    D : ndarray
+    D : numpy.ndarray
         The multi-dimensional distance profile
 
-    include : ndarray
+    include : numpy.ndarray
         A list of (zero-based) indices corresponding to the dimensions in `T` that
         must be included in the constrained multidimensional motif search.
         For more information, see Section IV D in:
@@ -69,18 +69,18 @@ def _apply_include(
         `DOI: 10.1109/ICDM.2017.66 \
         <https://www.cs.ucr.edu/~eamonn/Motif_Discovery_ICDM.pdf>`__
 
-    restricted_indices : ndarray, default None
+    restricted_indices : numpy.ndarray, default None
         A list of indices specified in `include` that reside in the first
         `include.shape[0]` rows
 
-    unrestricted_indices : ndarray, default None
+    unrestricted_indices : numpy.ndarray, default None
         A list of indices specified in `include` that do not reside in the first
         `include.shape[0]` rows
 
-    mask : ndarray, default None
+    mask : numpy.ndarray, default None
         A boolean mask to select for unrestricted indices
 
-    tmp_swap : ndarray, default None
+    tmp_swap : numpy.ndarray, default None
         A reusable array to aid in array element swapping
     """
     include = _preprocess_include(include)
@@ -92,7 +92,7 @@ def _apply_include(
         unrestricted_indices = include[include >= include.shape[0]]
 
     if mask is None:
-        mask = np.ones(include.shape[0], bool)
+        mask = np.ones(include.shape[0], dtype=bool)
         mask[restricted_indices] = False
 
     if tmp_swap is None:
@@ -111,36 +111,36 @@ def _multi_mass(Q, T, m, M_T, Σ_T, μ_Q, σ_Q):
 
     Parameters
     ----------
-    Q : ndarray
+    Q : numpy.ndarray
         Query array or subsequence
 
-    T : ndarray
+    T : numpy.ndarray
         Time series array or sequence
 
     m : int
         Window size
 
-    M_T : ndarray
+    M_T : numpy.ndarray
         Sliding mean for `T_A`
 
-    Σ_T : ndarray
+    Σ_T : numpy.ndarray
         Sliding standard deviation for `T_A`
 
-    μ_Q : ndarray
+    μ_Q : numpy.ndarray
         Mean value of `Q`
 
-    σ_Q : ndarray
+    σ_Q : numpy.ndarray
         Standard deviation of `Q`
 
     Returns
     -------
-    D : ndarray
+    D : numpy.ndarray
         Multi-dimensional distance profile
     """
     d, n = T.shape
     k = n - m + 1
 
-    D = np.empty((d, k), dtype="float64")
+    D = np.empty((d, k), dtype=np.float64)
 
     for i in range(d):
         if np.isinf(μ_Q[i]):
@@ -163,7 +163,7 @@ def _inverse_norm(n_bit=8):
 
     Returns
     -------
-    out : ndarray
+    out : numpy.ndarray
         Array of bin edges that can be used for data discretization
     """
     return norm.ppf(np.arange(1, (2 ** n_bit)) / (2 ** n_bit))
@@ -175,10 +175,10 @@ def _discretize(a, bins, right=True):
 
     Parameters
     ----------
-    a : ndarray
+    a : numpy.ndarray
         The input array
 
-    bins : ndarray
+    bins : numpy.ndarray
         The bin edges used to discretize `a`
 
     right : bool, default True
@@ -187,7 +187,7 @@ def _discretize(a, bins, right=True):
 
     Returns
     -------
-    out : ndarray
+    out : numpy.ndarray
         Discretized array
     """
     return np.digitize(a, bins, right=right)
@@ -200,14 +200,14 @@ def _subspace(D, k, include=None, discords=False):
 
     Parameters
     ----------
-    D : ndarray
+    D : numpy.ndarray
         The multi-dimensional distance profile
 
     k : int
         The subset number of dimensions out of `D = T.shape[0]`-dimensions to return
         the subspace for
 
-    include : ndarray, default None
+    include : numpy.ndarray, default None
         A list of (zero-based) indices corresponding to the dimensions in `T` that
         must be included in the constrained multidimensional motif search.
         For more information, see Section IV D in:
@@ -221,7 +221,7 @@ def _subspace(D, k, include=None, discords=False):
 
     Returns
     -------
-        S : ndarray
+        S : numpy.ndarray
         An array of that contains the `k`th-dimensional subspace for the subsequence
         with index equal to `motif_idx`
     """
@@ -254,7 +254,7 @@ def subspace(T, m, subseq_idx, nn_idx, k, include=None, discords=False, normaliz
 
     Parameters
     ----------
-    T : ndarray
+    T : numpy.ndarray
         The time series or sequence for which the multi-dimensional matrix profile,
         multi-dimensional matrix profile indices were computed
 
@@ -271,7 +271,7 @@ def subspace(T, m, subseq_idx, nn_idx, k, include=None, discords=False, normaliz
         The subset number of dimensions out of `D = T.shape[0]`-dimensions to return
         the subspace for
 
-    include : ndarray, default None
+    include : numpy.ndarray, default None
         A list of (zero-based) indices corresponding to the dimensions in `T` that
         must be included in the constrained multidimensional motif search.
         For more information, see Section IV D in:
@@ -290,9 +290,31 @@ def subspace(T, m, subseq_idx, nn_idx, k, include=None, discords=False, normaliz
 
     Returns
     -------
-        S : ndarray
+        S : numpy.ndarray
         An array of that contains the `k`th-dimensional subspace for the subsequence
         with index equal to `motif_idx`
+
+    See Also
+    --------
+    stumpy.mstump : Compute the multi-dimensional z-normalized matrix profile
+    stumpy.mstumped : Compute the multi-dimensional z-normalized matrix profile with
+        a distributed dask cluster
+
+    Examples
+    --------
+    >>> mps, indices = stumpy.mstump(
+    ...     np.array([[584., -11., 23., 79., 1001., 0., -19.],
+    ...               [  1.,   2.,  4.,  8.,   16., 0.,  32.]]),
+    ...     m=3)
+    >>> motifs_idx = np.argsort(mps, axis=1)[:, :2]
+    >>> stumpy.subspace(
+    ...     np.array([[584., -11., 23., 79., 1001., 0., -19.],
+    ...               [  1.,   2.,  4.,  8.,   16., 0.,  32.]],
+    ...     m=3,
+    ...     subseq_idx=motifs_idx[k][0],
+    ...     nn_idx=indices[k][motifs_idx[k][0]],
+    ...     k=1)
+    array([0, 1])
     """
     T, _, _ = core.preprocess(T, m)
     subseqs = core.z_norm(T[:, subseq_idx : subseq_idx + m], axis=1)
@@ -314,26 +336,24 @@ def subspace(T, m, subseq_idx, nn_idx, k, include=None, discords=False, normaliz
     return S
 
 
-def _query_mstump_profile(
+def _multi_distance_profile(
     query_idx, T_A, T_B, m, excl_zone, M_T, Σ_T, μ_Q, σ_Q, include=None, discords=False
 ):
     """
-    Multi-dimensional wrapper to compute the multi-dimensional matrix profile and
-    the multi-dimensional matrix profile index for a given query window within the times
-    series or sequence that is denoted by the `query_idx` index. Essentially, this is a
-    convenience wrapper around `_multi_mass`.
+    Multi-dimensional wrapper to compute the multi-dimensional distance profile for a
+    given query window within the times series or sequence that is denoted by the
+    `query_idx` index. Essentially, this is a convenience wrapper around `_multi_mass`.
 
     Parameters
     ----------
     query_idx : int
-        The window index to calculate the first multi-dimensional matrix profile and
-        multi-dimensional matrix profile indices
+        The window index to calculate the multi-dimensional distance profile for
 
-    T_A : ndarray
-        The time series or sequence for which the multi-dimensional matrix profile and
-        multi-dimensional matrix profile indices
+    T_A : numpy.ndarray
+        The time series or sequence for which the multi-dimensional distance profile
+        is computed
 
-    T_B : ndarray
+    T_B : numpy.ndarray
         The time series or sequence that contains your query subsequences
 
     m : int
@@ -342,19 +362,19 @@ def _query_mstump_profile(
     excl_zone : int
         The half width for the exclusion zone relative to the `query_idx`.
 
-    M_T : ndarray
+    M_T : numpy.ndarray
         Sliding mean for `T_A`
 
-    Σ_T : ndarray
+    Σ_T : numpy.ndarray
         Sliding standard deviation for `T_A`
 
-    μ_Q : ndarray
-        Sliding mean for `T_B`
+    μ_Q : numpy.ndarray
+        Sliding mean for the query subsequence `T_B`
 
-    σ_Q : ndarray
-        Sliding standard deviation for `T_B`
+    σ_Q : numpy.ndarray
+        Sliding standard deviation for the query subsequence `T_B`
 
-    include : ndarray, default None
+    include : numpy.ndarray, default None
         A list of (zero-based) indices corresponding to the dimensions in `T` that
         must be included in the constrained multidimensional motif search.
         For more information, see Section IV D in:
@@ -368,13 +388,9 @@ def _query_mstump_profile(
 
     Returns
     -------
-    P : ndarray
-        Multi-dimensional matrix profile for the window with index equal to
+    D : numpy.ndarray
+        Multi-dimensional distance profile for the window with index equal to
         `query_idx`
-
-    I : ndarray
-        Multi-dimensional matrix profile indices for the window with index
-        equal to `query_idx`
     """
     d, n = T_A.shape
     k = n - m + 1
@@ -398,24 +414,80 @@ def _query_mstump_profile(
     else:
         D[start_row_idx:].sort(axis=0, kind="mergesort")
 
-    D_prime = np.zeros(k)
+    D_prime = np.zeros(k, dtype=np.float64)
     for i in range(d):
         D_prime[:] = D_prime + D[i]
         D[i, :] = D_prime / (i + 1)
 
     core.apply_exclusion_zone(D, query_idx, excl_zone)
 
-    P = np.full(d, np.inf, dtype="float64")
-    I = np.full(d, -1, dtype="int64")
+    return D
 
-    for i in range(d):
-        min_index = np.argmin(D[i])
-        I[i] = min_index
-        P[i] = D[i, min_index]
-        if np.isinf(P[i]):  # pragma nocover
-            I[i] = -1
 
-    return P, I
+@core.non_normalized(maamp_multi_distance_profile)
+def multi_distance_profile(
+    query_idx, T, m, include=None, discords=False, normalize=True
+):
+    """
+    Multi-dimensional wrapper to compute the multi-dimensional distance profile for a
+    given query window within the times series or sequence that is denoted by the
+    `query_idx` index.
+
+    Parameters
+    ----------
+    query_idx : int
+        The window index to calculate the multi-dimensional distance profile for
+
+    T : numpy.ndarray
+        The multi-dimensional time series or sequence for which the multi-dimensional
+        distance profile will be returned
+
+    m : int
+        Window size
+
+    include : numpy.ndarray, default None
+        A list of (zero-based) indices corresponding to the dimensions in `T` that
+        must be included in the constrained multidimensional motif search.
+        For more information, see Section IV D in:
+
+        `DOI: 10.1109/ICDM.2017.66 \
+        <https://www.cs.ucr.edu/~eamonn/Motif_Discovery_ICDM.pdf>`__
+
+    discords : bool, default False
+        When set to `True`, this reverses the distance profile to favor discords rather
+        than motifs. Note that indices in `include` are still maintained and respected.
+
+    normalize : bool, default True
+        When set to `True`, this z-normalizes subsequences prior to computing distances.
+        Otherwise, this function gets re-routed to its complementary non-normalized
+        equivalent set in the `@core.non_normalized` function decorator.
+
+    Returns
+    -------
+    D : numpy.ndarray
+        Multi-dimensional distance profile for the window with index equal to
+        `query_idx`
+    """
+    T, M_T, Σ_T = core.preprocess(T, m)
+
+    if T.ndim <= 1:  # pragma: no cover
+        err = f"T is {T.ndim}-dimensional and must be at least 1-dimensional"
+        raise ValueError(f"{err}")
+
+    core.check_window_size(m, max_size=T.shape[1])
+
+    if include is not None:  # pragma: no cover
+        include = _preprocess_include(include)
+
+    excl_zone = int(
+        np.ceil(m / config.STUMPY_EXCL_ZONE_DENOM)
+    )  # See Definition 3 and Figure 3
+
+    D = _multi_distance_profile(
+        query_idx, T, T, m, excl_zone, M_T, Σ_T, M_T, Σ_T, include, discords
+    )
+
+    return D
 
 
 def _get_first_mstump_profile(
@@ -426,8 +498,8 @@ def _get_first_mstump_profile(
     and multi-dimensional matrix profile index for a given window within the
     times series or sequence that is denoted by the `start` index.
     Essentially, this is a convenience wrapper around `_multi_mass`. This is a
-    convenience wrapper for the `_query_mstump_profile` function but does not return
-    the multi-dimensional matrix profile subspace.
+    convenience wrapper for the `_multi_distance_profile` function but does not
+    return the multi-dimensional matrix profile subspace.
 
     Parameters
     ----------
@@ -435,12 +507,12 @@ def _get_first_mstump_profile(
         The window index to calculate the first multi-dimensional matrix profile,
         multi-dimensional matrix profile indices, and multi-dimensional subspace.
 
-    T_A : ndarray
+    T_A : numpy.ndarray
         The time series or sequence for which the multi-dimensional matrix profile,
         multi-dimensional matrix profile indices, and multi-dimensional subspace will be
         returned
 
-    T_B : ndarray
+    T_B : numpy.ndarray
         The time series or sequence that contains your query subsequences
 
     m : int
@@ -449,19 +521,19 @@ def _get_first_mstump_profile(
     excl_zone : int
         The half width for the exclusion zone relative to the `start`.
 
-    M_T : ndarray
+    M_T : numpy.ndarray
         Sliding mean for `T_A`
 
-    Σ_T : ndarray
+    Σ_T : numpy.ndarray
         Sliding standard deviation for `T_A`
 
-    μ_Q : ndarray
+    μ_Q : numpy.ndarray
         Sliding mean for `T_B`
 
-    σ_Q : ndarray
+    σ_Q : numpy.ndarray
         Sliding standard deviation for `T_B`
 
-    include : ndarray, default None
+    include : numpy.ndarray, default None
         A list of (zero-based) indices corresponding to the dimensions in `T` that
         must be included in the constrained multidimensional motif search.
         For more information, see Section IV D in:
@@ -475,17 +547,29 @@ def _get_first_mstump_profile(
 
     Returns
     -------
-    P : ndarray
+    P : numpy.ndarray
         Multi-dimensional matrix profile for the window with index equal to
         `start`
 
-    I : ndarray
+    I : numpy.ndarray
         Multi-dimensional matrix profile indices for the window with index
         equal to `start`
     """
-    P, I = _query_mstump_profile(
+    D = _multi_distance_profile(
         start, T_A, T_B, m, excl_zone, M_T, Σ_T, μ_Q, σ_Q, include, discords
     )
+
+    d = T_A.shape[0]
+    P = np.full(d, np.inf, dtype=np.float64)
+    I = np.full(d, -1, dtype=np.int64)
+
+    for i in range(d):
+        min_index = np.argmin(D[i])
+        I[i] = min_index
+        P[i] = D[i, min_index]
+        if np.isinf(P[i]):  # pragma nocover
+            I[i] = -1
+
     return P, I
 
 
@@ -500,7 +584,7 @@ def _get_multi_QT(start, T, m):
     start : int
         The window index for T_B from which to calculate the QT dot product
 
-    T : ndarray
+    T : numpy.ndarray
         The time series or sequence for which to compute the dot product
 
     m : int
@@ -508,17 +592,17 @@ def _get_multi_QT(start, T, m):
 
     Returns
     -------
-    QT : ndarray
+    QT : numpy.ndarray
         Given `start`, return the corresponding multi-dimensional QT
 
-    QT_first : ndarray
+    QT_first : numpy.ndarray
         Multi-dimensional QT for the first window
     """
     d = T.shape[0]
     k = T.shape[1] - m + 1
 
-    QT = np.empty((d, k), dtype="float64")
-    QT_first = np.empty((d, k), dtype="float64")
+    QT = np.empty((d, k), dtype=np.float64)
+    QT_first = np.empty((d, k), dtype=np.float64)
 
     for i in range(d):
         QT[i] = core.sliding_dot_product(T[i, start : start + m], T[i])
@@ -527,7 +611,12 @@ def _get_multi_QT(start, T, m):
     return QT, QT_first
 
 
-@njit(parallel=True, fastmath=True)
+@njit(
+    # "(i8, i8, i8, f8[:, :], f8[:, :], i8, i8, f8[:, :], f8[:, :], f8[:, :],"
+    # "f8[:, :], f8[:, :], f8[:, :], f8[:, :])",
+    parallel=True,
+    fastmath=True,
+)
 def _compute_multi_D(
     d, k, idx, D, T, m, excl_zone, M_T, Σ_T, QT_even, QT_odd, QT_first, μ_Q, σ_Q
 ):
@@ -546,10 +635,10 @@ def _compute_multi_D(
     idx : int
         The row index in `T`
 
-    D : ndarray
+    D : numpy.ndarray
         The output distance profile
 
-    T : ndarray
+    T : numpy.ndarray
         The time series or sequence for which to compute the matrix profile
 
     m : int
@@ -559,25 +648,25 @@ def _compute_multi_D(
         The half width for the exclusion zone relative to the current
         sliding window
 
-    M_T : ndarray
+    M_T : numpy.ndarray
         Sliding mean of time series, `T`
 
-    Σ_T : ndarray
+    Σ_T : numpy.ndarray
         Sliding standard deviation of time series, `T`
 
-    QT_even : ndarray
+    QT_even : numpy.ndarray
         Dot product between some query sequence,`Q`, and time series, `T`
 
-    QT_odd : ndarray
+    QT_odd : numpy.ndarray
         Dot product between some query sequence,`Q`, and time series, `T`
 
-    QT_first : ndarray
+    QT_first : numpy.ndarray
         QT for the first window relative to the current sliding window
 
-    μ_Q : ndarray
+    μ_Q : numpy.ndarray
         Mean of the query sequence, `Q`, relative to the current sliding window
 
-    σ_Q : ndarray
+    σ_Q : numpy.ndarray
         Standard deviation of the query sequence, `Q`, relative to the current
         sliding window
 
@@ -625,7 +714,11 @@ def _compute_multi_D(
     core.apply_exclusion_zone(D, idx, excl_zone)
 
 
-@njit(parallel=True, fastmath=True)
+@njit(
+    # "(i8, i8, f8[:, :], f8[:], i8, f8[:, :], i8[:, :])",
+    parallel=True,
+    fastmath=True,
+)
 def _compute_PI(d, idx, D, D_prime, range_start, P, I):
     """
     A Numba JIT-compiled version of mSTOMP for updating the matrix profile and matrix
@@ -639,20 +732,20 @@ def _compute_PI(d, idx, D, D_prime, range_start, P, I):
     idx : int
         The row index in `T`
 
-    D : ndarray
+    D : numpy.ndarray
         The distance profile
 
-    D_prime : ndarray
+    D_prime : numpy.ndarray
         A reusable array for storing the column-wise cumulative sum of `D`
 
     range_start : int
         The starting index value along `T` for which to start the matrix
         profile calculation
 
-    P : ndarray
+    P : numpy.ndarray
         The matrix profile
 
-    I : ndarray
+    I : numpy.ndarray
         The matrix profile indices
     """
     D_prime[:] = 0.0
@@ -690,7 +783,7 @@ def _mstump(
 
     Parameters
     ----------
-    T: ndarray
+    T: numpy.ndarray
         The time series or sequence for which to compute the multi-dimensional
         matrix profile
 
@@ -706,22 +799,22 @@ def _mstump(
         The half width for the exclusion zone relative to the current
         sliding window
 
-    M_T : ndarray
+    M_T : numpy.ndarray
         Sliding mean of time series, `T`
 
-    Σ_T : ndarray
+    Σ_T : numpy.ndarray
         Sliding standard deviation of time series, `T`
 
-    QT : ndarray
+    QT : numpy.ndarray
         Dot product between some query sequence,`Q`, and time series, `T`
 
-    QT_first : ndarray
+    QT_first : numpy.ndarray
         QT for the first window relative to the current sliding window
 
-    μ_Q : ndarray
+    μ_Q : numpy.ndarray
         Mean of the query sequence, `Q`, relative to the current sliding window
 
-    σ_Q : ndarray
+    σ_Q : numpy.ndarray
         Standard deviation of the query sequence, `Q`, relative to the current
         sliding window
 
@@ -732,7 +825,7 @@ def _mstump(
         The starting index value along T_B for which to start the matrix
         profile calculation. Default is 1.
 
-    include : ndarray, default None
+    include : numpy.ndarray, default None
         A list of (zero-based) indices corresponding to the dimensions in `T` that
         must be included in the constrained multidimensional motif search.
         For more information, see Section IV D in:
@@ -746,12 +839,12 @@ def _mstump(
 
     Returns
     -------
-    P : ndarray
+    P : numpy.ndarray
         The multi-dimensional matrix profile. Each row of the array corresponds
         to each matrix profile for a given dimension (i.e., the first row is the
         1-D matrix profile and the second row is the 2-D matrix profile).
 
-    I : ndarray
+    I : numpy.ndarray
         The multi-dimensional matrix profile index where each row of the array
         corresponds to each matrix profile index for a given dimension.
 
@@ -766,17 +859,17 @@ def _mstump(
     QT_even = QT.copy()
     d = T.shape[0]
 
-    P = np.empty((d, range_stop - range_start), dtype=float)
-    I = np.empty((d, range_stop - range_start), dtype=int)
-    D = np.empty((d, k), dtype=float)
-    D_prime = np.empty(k, dtype=float)
+    P = np.empty((d, range_stop - range_start), dtype=np.float64)
+    I = np.empty((d, range_stop - range_start), dtype=np.int64)
+    D = np.empty((d, k), dtype=np.float64)
+    D_prime = np.empty(k, dtype=np.float64)
     start_row_idx = 0
 
     if include is not None:
-        tmp_swap = np.empty((include.shape[0], k))
+        tmp_swap = np.empty((include.shape[0], k), dtype=np.float64)
         restricted_indices = include[include < include.shape[0]]
         unrestricted_indices = include[include >= include.shape[0]]
-        mask = np.ones(include.shape[0], bool)
+        mask = np.ones(include.shape[0], dtype=bool)
         mask[restricted_indices] = False
 
     for idx in range(range_start, range_stop):
@@ -813,7 +906,7 @@ def mstump(T, m, include=None, discords=False, normalize=True):
 
     Parameters
     ----------
-    T : ndarray
+    T : numpy.ndarray
         The time series or sequence for which to compute the multi-dimensional
         matrix profile. Each row in `T` represents data from a different
         dimension while each column in `T` represents data from the same
@@ -822,7 +915,7 @@ def mstump(T, m, include=None, discords=False, normalize=True):
     m : int
         Window size
 
-    include : list, ndarray, default None
+    include : list, numpy.ndarray, default None
         A list of (zero-based) indices corresponding to the dimensions in `T` that
         must be included in the constrained multidimensional motif search.
         For more information, see Section IV D in:
@@ -843,21 +936,39 @@ def mstump(T, m, include=None, discords=False, normalize=True):
 
     Returns
     -------
-    P : ndarray
+    P : numpy.ndarray
         The multi-dimensional matrix profile. Each row of the array corresponds
         to each matrix profile for a given dimension (i.e., the first row is
         the 1-D matrix profile and the second row is the 2-D matrix profile).
 
-    I : ndarray
+    I : numpy.ndarray
         The multi-dimensional matrix profile index where each row of the array
         corresponds to each matrix profile index for a given dimension.
 
+    See Also
+    --------
+    stumpy.mstumped : Compute the multi-dimensional z-normalized matrix profile with
+        a distributed dask cluster
+    stumpy.subspace : Compute the k-dimensional matrix profile subspace for a given
+        subsequence index and its nearest neighbor index
+
     Notes
     -----
     `DOI: 10.1109/ICDM.2017.66 \
     <https://www.cs.ucr.edu/~eamonn/Motif_Discovery_ICDM.pdf>`__
 
     See mSTAMP Algorithm
+
+    Examples
+    --------
+    >>> stumpy.mstump(
+    ...     np.array([[584., -11., 23., 79., 1001., 0., -19.],
+    ...               [  1.,   2.,  4.,  8.,   16., 0.,  32.]]),
+    ...     m=3)
+    (array([[0.        , 1.43947142, 0.        , 2.69407392, 0.11633857],
+            [0.777905  , 2.36179922, 1.50004632, 2.92246722, 0.777905  ]]),
+     array([[2, 4, 0, 1, 0],
+            [4, 4, 0, 1, 0]]))
     """
     T_A = T
     T_B = T_A
@@ -880,8 +991,8 @@ def mstump(T, m, include=None, discords=False, normalize=True):
         np.ceil(m / config.STUMPY_EXCL_ZONE_DENOM)
     )  # See Definition 3 and Figure 3
 
-    P = np.empty((d, k), dtype="float64")
-    I = np.empty((d, k), dtype="int64")
+    P = np.empty((d, k), dtype=np.float64)
+    I = np.empty((d, k), dtype=np.int64)
 
     start = 0
     stop = k
