@@ -14,7 +14,12 @@ from .stump import _stump
 logger = logging.getLogger(__name__)
 
 
-@njit(parallel=True, fastmath=True)
+@njit(
+    # "(f8[:], f8[:], i8, f8[:], f8[:], f8[:], f8[:], f8[:], i8, i8, f8[:], f8[:],"
+    # "i8[:], optional(i8))",
+    parallel=True,
+    fastmath=True,
+)
 def _prescrump(
     T_A,
     T_B,
@@ -36,30 +41,30 @@ def _prescrump(
 
     Parameters
     ----------
-    T_A : ndarray
+    T_A : numpy.ndarray
         The time series or sequence for which to compute the matrix profile
 
-    T_B : ndarray
+    T_B : numpy.ndarray
         The time series or sequence that will be used to annotate T_A. For every
         subsequence in T_A, its nearest neighbor in T_B will be recorded.
 
     m : int
         Window size
 
-    M_T : ndarray
+    M_T : numpy.ndarray
         Sliding window mean for T_A
 
-    Σ_T : ndarray
+    Σ_T : numpy.ndarray
         Sliding window standard deviation for T_A
 
-    μ_Q : ndarray
+    μ_Q : numpy.ndarray
         Mean of the query sequence, `Q`, relative to the current sliding window in `T_B`
 
-    σ_Q : ndarray
+    σ_Q : numpy.ndarray
         Standard deviation of the query sequence, `Q`, relative to the current
         sliding window in `T_B`
 
-    QT : ndarray
+    QT : numpy.ndarray
         Sliding dot product between `Q` in `T_B` and `T_A`
 
     i : int
@@ -69,13 +74,13 @@ def _prescrump(
         The sampling interval that defaults to
         `int(np.ceil(m / config.STUMPY_EXCL_ZONE_DENOM))`
 
-    squared_distance_profile : ndarray
+    squared_distance_profile : numpy.ndarray
         A reusable array to store the computed squared distance profile
 
-    P_squared : ndarray
+    P_squared : numpy.ndarray
         The squared matrix profile
 
-    I : ndarray
+    I : numpy.ndarray
         The matrix profile indices
 
     excl_zone : int
@@ -156,13 +161,13 @@ def prescrump(T_A, m, T_B=None, s=None, normalize=True):
 
     Parameters
     ----------
-    T_A : ndarray
+    T_A : numpy.ndarray
         The time series or sequence for which to compute the matrix profile
 
     m : int
         Window size
 
-    T_B : ndarray, default None
+    T_B : numpy.ndarray, default None
         The time series or sequence that will be used to annotate T_A. For every
         subsequence in T_A, its nearest neighbor in T_B will be recorded.
 
@@ -177,10 +182,10 @@ def prescrump(T_A, m, T_B=None, s=None, normalize=True):
 
     Returns
     -------
-    P : ndarray
+    P : numpy.ndarray
         Matrix profile
 
-    I : ndarray
+    I : numpy.ndarray
         Matrix profile indices
 
     Notes
@@ -217,14 +222,14 @@ def prescrump(T_A, m, T_B=None, s=None, normalize=True):
     n_A = T_A.shape[0]
     n_B = T_B.shape[0]
     l = n_A - m + 1
-    P_squared = np.full(l, np.inf)
+    P_squared = np.full(l, np.inf, dtype=np.float64)
     I = np.full(l, -1, dtype=np.int64)
-    squared_distance_profile = np.empty(n_B - m + 1)
+    squared_distance_profile = np.empty(n_B - m + 1, dtype=np.float64)
 
     if s is None:  # pragma: no cover
         s = excl_zone
 
-    for i in np.random.permutation(range(0, l, s)):
+    for i in np.random.permutation(range(0, l, s)).astype(np.int64):
         QT = core.sliding_dot_product(T_A[i : i + m], T_B)
         _prescrump(
             T_A,
@@ -262,10 +267,10 @@ class scrump:
 
     Parameters
     ----------
-    T_A : ndarray
+    T_A : numpy.ndarray
         The time series or sequence for which to compute the matrix profile
 
-    T_B : ndarray
+    T_B : numpy.ndarray
         The time series or sequence that will be used to annotate T_A. For every
         subsequence in T_A, its nearest neighbor in T_B will be recorded.
 
@@ -297,10 +302,10 @@ class scrump:
 
     Attributes
     ----------
-    P_ : ndarray
+    P_ : numpy.ndarray
         The updated matrix profile
 
-    I_ : ndarray
+    I_ : numpy.ndarray
         The updated matrix profile indices
 
     Methods
@@ -310,12 +315,39 @@ class scrump:
         additional new distances (limited by `percentage`) that make up the full
         distance matrix.
 
+    See Also
+    --------
+    stumpy.stump : Compute the z-normalized matrix profile
+    stumpy.stumped : Compute the z-normalized matrix profile with a distributed dask
+        cluster
+    stumpy.gpu_stump : Compute the z-normalized matrix profile with one or more GPU
+        devices
+
     Notes
     -----
     `DOI: 10.1109/ICDM.2018.00099 \
     <https://www.cs.ucr.edu/~eamonn/SCRIMP_ICDM_camera_ready_updated.pdf>`__
 
     See Algorithm 1 and Algorithm 2
+
+    Examples
+    --------
+    >>> approx_mp = stumpy.scrump(
+    ...     np.array([584., -11., 23., 79., 1001., 0., -19.]),
+    ...     m=3)
+    >>> approx_mp.update()
+    >>> approx_mp._P
+    array([[2.982409  ,        inf, 2.982409  ],
+           [3.28412702,        inf, 3.28412702],
+           [       inf,        inf,        inf],
+           [2.982409  , 2.982409  ,        inf],
+           [3.28412702, 3.28412702,        inf]])
+    >>> approx_mp._I
+    array([[ 3, -1,  3],
+           [ 4, -1,  4],
+           [-1, -1, -1],
+           [ 0,  0, -1],
+           [ 1,  1, -1]])
     """
 
     def __init__(
@@ -334,13 +366,13 @@ class scrump:
 
         Parameters
         ----------
-        T_A : ndarray
+        T_A : numpy.ndarray
             The time series or sequence for which to compute the matrix profile
 
         m : int
             Window size
 
-        T_B : ndarray, default None
+        T_B : numpy.ndarray, default None
             The time series or sequence that will be used to annotate T_A. For every
             subsequence in T_A, its nearest neighbor in T_B will be recorded.
 
@@ -446,7 +478,7 @@ class scrump:
         if self._ignore_trivial:
             self._diags = np.random.permutation(
                 range(self._excl_zone + 1, self._n_A - self._m + 1)
-            )
+            ).astype(np.int64)
             if self._diags.shape[0] == 0:  # pragma: no cover
                 max_m = core.get_max_window_size(self._T_A.shape[0])
                 raise ValueError(
@@ -456,7 +488,7 @@ class scrump:
         else:
             self._diags = np.random.permutation(
                 range(-(self._n_A - self._m + 1) + 1, self._n_B - self._m + 1)
-            )
+            ).astype(np.int64)
 
         self._n_threads = numba.config.NUMBA_NUM_THREADS
         self._percentage = np.clip(percentage, 0.0, 1.0)
@@ -465,7 +497,7 @@ class scrump:
             self._diags, self._m, self._n_A, self._n_B
         )
         self._chunk_diags_ranges = core._get_array_ranges(
-            self._ndist_counts, self._n_chunks, truncate=True
+            self._ndist_counts, self._n_chunks, True
         )
         self._n_chunks = self._chunk_diags_ranges.shape[0]
         self._chunk_idx = 0
