@@ -41,7 +41,7 @@ def _bfs_indices(n):
 
     Returns
     -------
-    level_idx : ndarray
+    level_idx : numpy.ndarray
         The breadth first search (level order) indices
     """
     if n == 1:  # pragma: no cover
@@ -90,16 +90,16 @@ def _normalize_pan(pan, ms, bfs_indices, n_processed):
 
     Parameters
     ----------
-    pan : ndarray
+    pan : numpy.ndarray
         The pan matrix profile
 
-    ms : ndarray
+    ms : numpy.ndarray
         The breadth-first-search sorted subsequence window sizes
 
-    bfs_indices : ndarray
+    bfs_indices : numpy.ndarray
         The breadth-first-search indices
 
-    n_processed : ndarray
+    n_processed : numpy.ndarray
         The number of subsequence window sizes and breadth-first-search indices to
         normalize
 
@@ -119,16 +119,16 @@ def _contrast_pan(pan, threshold, bfs_indices, n_processed):
 
     Parameters
     ----------
-    pan : ndarray
+    pan : numpy.ndarray
         The pan matrix profile
 
     threshold : float
         The distance threshold value in which to center the pan matrix profile around
 
-    bfs_indices : ndarray
+    bfs_indices : numpy.ndarray
         The breadth-first-search indices
 
-    n_processed : ndarray
+    n_processed : numpy.ndarray
         The number of breadth-first-search indices to apply contrast to
 
     Returns
@@ -139,7 +139,7 @@ def _contrast_pan(pan, threshold, bfs_indices, n_processed):
     l = n_processed * pan.shape[1]
     tmp = pan[idx].argsort(kind="mergesort", axis=None)
     ranks = np.empty(l, dtype=np.int64)
-    ranks[tmp] = np.arange(l)
+    ranks[tmp] = np.arange(l).astype(np.int64)
 
     percentile = np.full(ranks.shape, np.nan)
     percentile[:l] = np.linspace(0, 1, l)
@@ -154,16 +154,16 @@ def _binarize_pan(pan, threshold, bfs_indices, n_processed):
 
     Parameters
     ----------
-    pan : ndarray
+    pan : numpy.ndarray
         The pan matrix profile
 
     threshold : float
         The distance threshold value in which to center the pan matrix profile around
 
-    bfs_indices : ndarray
+    bfs_indices : numpy.ndarray
         The breadth-first-search indices
 
-    n_processed : ndarray
+    n_processed : numpy.ndarray
         The number of breadth-first-search indices to binarize
 
     Returns
@@ -182,7 +182,7 @@ class _stimp:
 
     Parameters
     ----------
-    T : ndarray
+    T : numpy.ndarray
         The time series or sequence for which to compute the pan matrix profile
 
     m_start : int, default 3
@@ -225,11 +225,11 @@ class _stimp:
 
     Attributes
     ----------
-    PAN_ : ndarray
+    PAN_ : numpy.ndarray
         The transformed (i.e., normalized, contrasted, binarized, and repeated)
         pan matrix profile
 
-    M_ : ndarray
+    M_ : numpy.ndarray
         The full list of (breadth first search (level) ordered) subsequence window
         sizes
 
@@ -264,7 +264,7 @@ class _stimp:
 
         Parameters
         ----------
-        T : ndarray
+        T : numpy.ndarray
             The time series or sequence for which to compute the pan matrix profile
 
         min_m : int, default 3
@@ -308,14 +308,14 @@ class _stimp:
         self._T = T
         if max_m is None:
             max_m = max(min_m + 1, core.get_max_window_size(self._T.shape[0]))
-            M = np.arange(min_m, max_m + 1, step)
+            M = np.arange(min_m, max_m + 1, step).astype(np.int64)
         else:
             min_m, max_m = sorted([min_m, max_m])
             M = np.arange(
                 max(3, min_m),
                 min(core.get_max_window_size(self._T.shape[0]), max_m) + 1,
                 step,
-            )
+            ).astype(np.int64)
         self._bfs_indices = _bfs_indices(M.shape[0])
         self._M = M[self._bfs_indices]
         self._n_processed = 0
@@ -328,7 +328,9 @@ class _stimp:
         )
         self._mp_func = partial_mp_func
 
-        self._PAN = np.full((self._M.shape[0], self._T.shape[0]), fill_value=np.inf)
+        self._PAN = np.full(
+            (self._M.shape[0], self._T.shape[0]), fill_value=np.inf, dtype=np.float64
+        )
 
     def update(self):
         """
@@ -467,7 +469,7 @@ class stimp(_stimp):
 
     Parameters
     ----------
-    T : ndarray
+    T : numpy.ndarray
         The time series or sequence for which to compute the pan matrix profile
 
     m_start : int, default 3
@@ -495,11 +497,11 @@ class stimp(_stimp):
 
     Attributes
     ----------
-    PAN_ : ndarray
+    PAN_ : numpy.ndarray
         The transformed (i.e., normalized, contrasted, binarized, and repeated)
         pan matrix profile
 
-    M_ : ndarray
+    M_ : numpy.ndarray
         The full list of (breadth first search (level) ordered) subsequence window
         sizes
 
@@ -509,12 +511,25 @@ class stimp(_stimp):
         Compute the next matrix profile using the next available (breadth-first-search
         (level) ordered) subsequence window size and update the pan matrix profile
 
+    See Also
+    --------
+    stumpy.stimped : Compute the Pan Matrix Profile with a distributed dask cluster
+    stumpy.gpu_stimp : Compute the Pan Matrix Profile with with one or more GPU devices
+
     Notes
     -----
     `DOI: 10.1109/ICBK.2019.00031 \
     <https://www.cs.ucr.edu/~eamonn/PAN_SKIMP%20%28Matrix%20Profile%20XX%29.pdf>`__
 
     See Table 2
+
+    Examples
+    --------
+    >>> pmp = stumpy.stimp(np.array([584., -11., 23., 79., 1001., 0., -19.]))
+    >>> pmp.update()
+    >>> pmp.PAN_
+    array([[0., 1., 1., 1., 1., 1., 1.],
+           [0., 1., 1., 1., 1., 1., 1.]])
     """
 
     def __init__(
@@ -532,7 +547,7 @@ class stimp(_stimp):
 
         Parameters
         ----------
-        T : ndarray
+        T : numpy.ndarray
             The time series or sequence for which to compute the pan matrix profile
 
         min_m : int, default 3
@@ -583,7 +598,7 @@ class stimped(_stimp):
             scope of this library. Please refer to the Dask Distributed
             documentation.
 
-    T : ndarray
+    T : numpy.ndarray
         The time series or sequence for which to compute the pan matrix profile
 
     m_start : int, default 3
@@ -600,11 +615,11 @@ class stimped(_stimp):
 
     Attributes
     ----------
-    PAN_ : ndarray
+    PAN_ : numpy.ndarray
         The transformed (i.e., normalized, contrasted, binarized, and repeated)
         pan matrix profile
 
-    M_ : ndarray
+    M_ : numpy.ndarray
         The full list of (breadth first search (level) ordered) subsequence window
         sizes
 
@@ -614,12 +629,30 @@ class stimped(_stimp):
         Compute the next matrix profile using the next available (breadth-first-search
         (level) ordered) subsequence window size and update the pan matrix profile
 
+    See Also
+    --------
+    stumpy.stimp : Compute the Pan Matrix Profile
+    stumpy.gpu_stimp : Compute the Pan Matrix Profile with with one or more GPU devices
+
     Notes
     -----
     `DOI: 10.1109/ICBK.2019.00031 \
     <https://www.cs.ucr.edu/~eamonn/PAN_SKIMP%20%28Matrix%20Profile%20XX%29.pdf>`__
 
     See Table 2
+
+    Examples
+    --------
+    >>> from dask.distributed import Client
+    >>> if __name__ == "__main__":
+    ...     dask_client = Client()
+    ...     pmp = stumpy.stimped(
+    ...         dask_client,
+    ...         np.array([584., -11., 23., 79., 1001., 0., -19.]))
+    ...     pmp.update()
+    ...     pmp.PAN_
+    array([[0., 1., 1., 1., 1., 1., 1.],
+           [0., 1., 1., 1., 1., 1., 1.]])
     """
 
     def __init__(
@@ -642,7 +675,7 @@ class stimped(_stimp):
             scope of this library. Please refer to the Dask Distributed
             documentation.
 
-        T : ndarray
+        T : numpy.ndarray
             The time series or sequence for which to compute the pan matrix profile
 
         min_m : int, default 3
