@@ -16,7 +16,7 @@ class stumpi:
 
     Parameters
     ----------
-    T : ndarray
+    T : numpy.ndarray
         The time series or sequence for which the matrix profile and matrix profile
         indices will be returned
 
@@ -34,19 +34,19 @@ class stumpi:
 
     Attributes
     ----------
-    P_ : ndarray
+    P_ : numpy.ndarray
         The updated matrix profile for `T`
 
-    I_ : ndarray
+    I_ : numpy.ndarray
         The updated matrix profile indices for `T`
 
-    left_P_ : ndarray
+    left_P_ : numpy.ndarray
         The updated left matrix profile for `T`
 
-    left_I_ : ndarray
+    left_I_ : numpy.ndarray
         The updated left matrix profile indices for `T`
 
-    T_ : ndarray
+    T_ : numpy.ndarray
         The updated time series or sequence for which the matrix profile and matrix
         profile indices are computed
 
@@ -64,6 +64,17 @@ class stumpi:
     See Table V
 
     Note that line 11 is missing an important `sqrt` operation!
+
+    Examples
+    --------
+    >>> stream = stumpy.stumpi(
+    ...     np.array([584., -11., 23., 79., 1001., 0.]),
+    ...     m=3)
+    >>> stream.update(-19.0)
+    >>> stream.left_P_
+    array([       inf, 3.00009263, 2.69407392, 3.05656417])
+    >>> stream.left_I_
+    array([-1,  0,  1,  2])
     """
 
     def __init__(self, T, m, egress=True, normalize=True):
@@ -72,7 +83,7 @@ class stumpi:
 
         Parameters
         ----------
-        T : ndarray
+        T : numpy.ndarray
             The time series or sequence for which the matrix profile and matrix profile
             indices will be returned
 
@@ -101,7 +112,7 @@ class stumpi:
         self._P = mp[:, 0].astype(np.float64)
         self._I = mp[:, 1].astype(np.int64)
         self._left_I = mp[:, 2].astype(np.int64)
-        self._left_P = np.empty(self._P.shape)
+        self._left_P = np.empty(self._P.shape, dtype=np.float64)
         self._left_P[:] = np.inf
 
         self._T, self._M_T, self._Σ_T = core.preprocess(self._T, self._m)
@@ -114,7 +125,7 @@ class stumpi:
         Q = self._T[-m:]
         self._QT = core.sliding_dot_product(Q, self._T)
         if self._egress:
-            self._QT_new = np.empty(self._QT.shape[0])
+            self._QT_new = np.empty(self._QT.shape[0], dtype=np.float64)
             self._n_appended = 0
 
     def update(self, t):
@@ -219,7 +230,7 @@ class stumpi:
         n = self._T.shape[0]
         l = n - self._m + 1
         T_new = np.append(self._T, t)
-        QT_new = np.empty(self._QT.shape[0] + 1)
+        QT_new = np.empty(self._QT.shape[0] + 1, dtype=np.float64)
         S = T_new[l:]
         t_drop = T_new[l - 1]
 
